import { GoogleSpreadsheet } from 'google-spreadsheet';
import log from 'npmlog';
import { GlobalConfig } from './types';
import { Notey } from './bots/notey';
import { Bard } from './bots/bard';
import { Stemswarden } from './bots/stemswarden';
import { Ordermaster } from './bots/ordermaster';
import { Dissonator, DissonatorController } from './bots/dissonators';

export const start = async (config: GlobalConfig) => {
  log.info('manager', 'starting bots');
  const doc = new GoogleSpreadsheet(config.spreadsheetId);
  await doc.useServiceAccountAuth(config.googleAuth);
  await doc.loadInfo();

  /* Notey */
  const _notey = new Notey(config);

  /* Core */
  const _bard = new Bard(config, doc);
  const _stemswarden = new Stemswarden(config, doc);
  const _ordermaster = new Ordermaster(config, doc);

  /* Dissonators */
  const dissonators = config.dissonators.bots.map(
    dissonatorConfig =>
      new Dissonator(
        config,
        dissonatorConfig,
        doc,
        config.dissonators.phrasesSheetId
      )
  );
  const _dissonatorController = new DissonatorController(
    dissonators,
    config.dissonators.controlChannelId,
    config.generalChannelId
  );
};
